@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: iso-8859-1 -*-
 # vim: set ft=python ts=3 sw=3 expandtab:
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -9,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2007,2010 Kenneth J. Pronovici.
+# Copyright (c) 2007,2010,2015 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -26,8 +25,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python 2 (>= 2.7)
-# Project  : Cedar Backup, release 2
+# Language : Python 3 (>= 3.4)
+# Project  : Cedar Backup, release 3
 # Purpose  : Tests span tool functionality.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -37,7 +36,7 @@
 ########################################################################
 
 """
-Unit tests for CedarBackup2/tools/span.py.
+Unit tests for CedarBackup3/tools/span.py.
 
 Code Coverage
 =============
@@ -77,9 +76,9 @@ Full vs. Reduced Tests
 ########################################################################
 
 import unittest
-from CedarBackup2.testutil import captureOutput
-from CedarBackup2.tools.span import _usage, _version
-from CedarBackup2.tools.span import Options
+from CedarBackup3.testutil import captureOutput
+from CedarBackup3.tools.span import _usage, _version
+from CedarBackup3.tools.span import Options
 
 
 #######################################################################
@@ -160,20 +159,10 @@ class TestSpanOptions(unittest.TestCase):
 # Suite definition
 #######################################################################
 
-# pylint: disable=C0330
 def suite():
    """Returns a suite containing all the test cases in this module."""
-   return unittest.TestSuite((
-                              unittest.makeSuite(TestFunctions, 'test'),
-                              unittest.makeSuite(TestSpanOptions, 'test'),
-                            ))
-
-
-########################################################################
-# Module entry point
-########################################################################
-
-# When this module is executed from the command-line, run its tests
-if __name__ == '__main__':
-   unittest.main()
+   tests = [ ]
+   tests.append(unittest.makeSuite(TestFunctions, 'test'))
+   tests.append(unittest.makeSuite(TestSpanOptions, 'test'))
+   return unittest.TestSuite(tests)
 
